@@ -122,7 +122,7 @@ class DateDirRepo:
         if self.stash_path:
             original_report['datedir_repo_filepath'] = filename
         os.chmod(filename, wanted_file_permission)
-        return report['id']
+        return [report['id']]
 
     def republish(self, publisher):
         """Republish the contents of the DateDirRepo to another publisher.
